Crate kcr_logging_banzaicloud_io

Crate kcr_logging_banzaicloud_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the logging.banzaicloud.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

logging.banzaicloud.io/v1alpha1

  • ClusterFlow
  • ClusterOutput
  • Flow
  • Logging
  • Output

logging.banzaicloud.io/v1beta1

  • ClusterFlow
  • ClusterOutput
  • Flow
  • Output
  • SyslogNGClusterFlow
  • SyslogNGClusterOutput
  • SyslogNGFlow
  • SyslogNGOutput

Modules

v1alpha1
v1beta1